@@ -3,7 +3,8 @@
  *                                                                    
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003 Henrik Sandklef                    
+ *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
+ *                      2009  Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -42,7 +43,7 @@
  */
 int
 xnee_set_callback (xnee_data *xd,
-		   callback_ptrptr, 
+		   callback_ptrptr dest, 
 		   const char *sym_name);
 
 /* OLD VERSION
