@@ -635,6 +635,16 @@ static xnee_option_t xnee_options_impl[] =
       XNEE_OPTION_VISIBLE
     },
 
+    {
+      XNEE_MAX_WINDOW_MOVES,
+      "max-window-moves",
+      "mwm",
+      NULL,
+      "Maximum times Xnee will try to move a window to the position it was in when recorded",
+      XNEE_REPLAY_OPTION,
+      XNEE_OPTION_VISIBLE
+    },
+
 
     {
       XNEE_LAST_OPTION,
@@ -1494,8 +1504,16 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
       *args_used = 0;
       break;
 
+    case XNEE_MAX_WINDOW_MOVES:
+      verbose_option("XNEE_MAX_WINDOW_MOVES");
+      opt_int = xnee_str2int(xd, opt_and_args[1]);
+      ret = xnee_set_max_nr_of_moves(xd, opt_int);
+      *args_used = 1;
+      break;
 
 
+      
+
 
 
       /*
